@@ -29,24 +29,39 @@ class GPGSVrec:
         self.sinV=d[3]
 
         self.idch1=d[4]
-        self.evch1=d[4]
-        self.azch1=d[4]
-        self.snrch1=d[4]
+        self.evch1=d[5]
+        self.azch1=d[6]
+        self.snrch1=d[7]
+        try:
+            self.idch2=d[8]
+            self.evch2=d[9]
+            self.azch2=d[10]
+            self.snrch2=d[11]
 
-        self.idch2=d[5]
-        self.evch2=d[5]
-        self.azch2=d[5]
-        self.snrch2=d[5]
+            self.idch3=d[12]
+            self.evch3=d[13]
+            self.azch3=d[14]
+            self.snrch3=d[15]
 
-        self.idch3=d[6]
-        self.evch3=d[6]
-        self.azch3=d[6]
-        self.snrch3=d[6]
-
-        self.idch4=d[7]
-        self.evch4=d[7]
-        self.azch4=d[7]
-        self.snrch4=d[7].split('*')[0]
+            self.idch4=d[16]
+            self.evch4=d[17]
+            self.azch4=d[18]
+            self.snrch4=d[19].split('*')[0]
+        except:
+            print("Data Insufficient\n")
+            self.idch2=''
+            self.evch2=''
+            self.azch2=''
+            self.snrch2=''
+            self.idch3=''
+            self.evch3=''
+            self.azch3=''
+            self.snrch3=''
+            self.idch4=''
+            self.evch4=''
+            self.azch4=''
+            self.snrch4=''
+            
         x=self
         self.print=("Number of Messages1: "+x.nofmsg+" Message Number: "+x.msgno+" Satellites in View: "+x.sinV+
       " Satellite ID Ch1: "+x.idch1+" Elevation (degree) Ch1: "+x.evch1+" Azimuth (degree) ch1: "+x.azch1+" SNR ch1 (dBHz): "+x.snrch1+
